@@ -3,6 +3,7 @@ from . import papi_low
 from . import events
 from . import consts
 from . import exceptions
+from . import structs
 
 __all__ = [
     "papi_high",
@@ -10,4 +11,5 @@ __all__ = [
     "events",
     "consts",
     "exceptions",
+    "structs",
 ]
